@@ -18,7 +18,7 @@ along with copyblock; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 /*@LICENSE*/
-// $Id: copyblock.cxx,v 1.4 2006/10/20 20:38:26 zeldan Exp $
+// $Id: copyblock.cxx,v 1.7 2006/11/10 21:17:24 zeldan Exp $
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -42,7 +42,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 using namespace std;
 
 
-static const char * COPYRIGHT = "Copyright (C)  2005-2006  Daniele Zelante ";
+static const char * COPYRIGHT = "Copyright (C)  2005-2006  Daniele Zelante <zeldan@email.it>";
 
 const char * zeldan()
 {
@@ -214,7 +214,7 @@ fileinfo_t fileinfo(const int fd)
 	struct stat s;
 	if (-1==fstat(fd,&s)) myerror("fstat");
 
-	fi._ok = S_ISREG(s.st_mode) || S_ISBLK(s.st_mode) || S_ISCHR(s.st_mode);
+	fi._ok = (S_ISREG(s.st_mode) || S_ISBLK(s.st_mode) || S_ISCHR(s.st_mode) || S_ISFIFO(s.st_mode)) && !isatty(fd);
 	fi._regular = S_ISREG(s.st_mode);
 	fi._size = s.st_size;
 	if (fi._size) fi._sizeable = true;
@@ -260,6 +260,9 @@ bool isdirty(const char * buf, size_t len)
 void blockread(const char * filename, const size_t blocksize, const off_t maxsize, bool sparse)
 {
 	fileinfo_t nfo1 = fileinfo(1);
+	if (!nfo1._ok)
+		myfatal("invalid stdout");
+		
 	if (!nfo1._regular && sparse) 
 	{
 		cerr << "warn: ignoring [-z] when writing to non-regular file " << endl;
@@ -351,6 +354,8 @@ void blockwrite(const char * filename, const size_t blocksize, const off_t maxsi
 	if (!fdonfo._ok) myfatal("invalid output file type \n");
 	
 	fileinfo_t nfo0 = fileinfo(0);
+	if (!nfo0._ok)
+		myfatal("invalid stdin");
 
 	off_t devsize = 0;
 	
